# -*- coding: utf-8 -*-
"""
Regarding to the main documentation you find here all the stuff which is related to the records. You can
imagine these record things as the in-application-currency. They are achieved and structured in the
:ref:`base-sources`. They are gathered by the :ref:`readers`. And they are combined, sorted, dismissed and
reorganized by the processor.

.. note:: This layer is not meant to be adapted in normal.
"""



# -*- coding: utf-8 -*-

"""
This package is meant for contributions to the project, that are not part of the core libraries but may be
useful in general.
"""
import logging
from functools import cmp_to_key

log = logging.getLogger(__name__)


def plr_sort_within_themes_by_type_code(extract):
    """
    This method sorts a plr list (while keeping the theme order) according to the TypeCode.

    Args:
        extract

    Returns:
        The sorted extract
    """
    real_estate = extract.real_estate

    if log.isEnabledFor(logging.DEBUG):
        for public_law_restriction in real_estate.public_law_restrictions:
            log.debug("START plr_sort_within_themes_by_type_code: plr theme {}, type_code {}".
                      format(public_law_restriction.theme.code, public_law_restriction.type_code))

    def cmp(a, b):
        if a.theme.code == b.theme.code:
            # Only impact the order of elements which are in the same theme
            value_a = a.type_code
            value_b = b.type_code
            if value_a and value_b:
                if value_a < value_b:
                    ret = -1
                elif value_a == value_b:
                    ret = 0
                else:
                    ret = 1
            else:
                ret = 0
        else:
            ret = 0
        return ret

    real_estate.public_law_restrictions = sorted(real_estate.public_law_restrictions, key=cmp_to_key(cmp))

    if log.isEnabledFor(logging.DEBUG):
        for public_law_restriction in real_estate.public_law_restrictions:
            log.debug("DONE plr_sort_within_themes_by_type_code: plr theme {}, type_code {}".
                      format(public_law_restriction.theme.code, public_law_restriction.type_code))

    return extract



# -*- coding: utf-8 -*-

import os
import re
from setuptools import setup, find_packages

HERE = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(HERE, 'README.rst')) as f:
    README = f.read()
with open(os.path.join(HERE, 'CHANGES.rst')) as f:
    CHANGES = f.read()
with open('requirements.txt') as f:
    re_ = a = re.compile(r'(.+)==')
    recommend = f.read().splitlines()
requires = [re_.match(r).group(1) for r in recommend]

setup(
    name='pyramid_oereb',
    version='1.7.4',
    description='pyramid_oereb, extension for pyramid web frame work to provide '
            'a basic server part for the oereb project',
    long_description='{readme}\n\n{changes}'.format(readme=README, changes=CHANGES),
    long_description_content_type='text/x-rst',
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Framework :: Pyramid",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: WSGI :: Application"
    ],
    license='BSD 2',
    author='Clemens Rudert',
    author_email='clemens.rudert@bl.ch',
    url='https://github.com/openoereb/pyramid_oereb',
    keywords='pyramid oereb',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    extras_require={
        'recommend': recommend,
        'no-version': requires,
    },
    entry_points={
        'paste.app_factory': [
            'main = pyramid_oereb:main'
        ],
        'console_scripts': [
            'create_standard_model = pyramid_oereb.standard.create_standard_models:create_standard_model',
            'create_oereblex_model = pyramid_oereb.contrib.scripts:create_oereblex_model',
            'create_standard_tables = pyramid_oereb.standard.create_tables:create_standard_tables',
            'create_theme_tables = pyramid_oereb.standard.create_tables:create_theme_tables',
            'create_standard_yaml = pyramid_oereb.standard.create_yaml:create_standard_yaml',
            'drop_standard_tables = pyramid_oereb.standard.drop_tables:drop_standard_tables',
            'create_legend_entries = pyramid_oereb.standard.load_legend_entries:run',
            'import_federal_topic = pyramid_oereb.standard.import_federal_topic:run',
            'create_stats_tables = pyramid_oereb.contrib.stats.scripts.create_stats_tables:create_stats_tables'  # noqa: E501
        ]
    }
)
